Class: Kaltura::Constants::BatchJob::OrderBy
- Inherits:
-
Object
- Object
- Kaltura::Constants::BatchJob::OrderBy
- Defined in:
- lib/kaltura/constants/batch_job.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- STATUS_ASC =
order by status ascending.
"+status"- STATUS_DESC =
order by status descending.
"-status"- QUEUE_TIME_ASC =
order by queue time ascending.
"+queueTime"- QUEUE_TIME_DESC =
order by queue time descending.
"-queueTime"- FINISH_TIME_ASC =
order by finish time ascending.
"+finishTime"- FINISH_TIME_DESC =
order by finish time descending.
"-finishTime"- CREATED_AT_ASC =
order by created at ascending.
"+createdAt"- CREATED_AT_DESC =
order by created_at descending.
"-createdAt"- EXECUTION_ATTEMPTS_ASC =
order by execution attempts ascending.
"+executionAttempts"- EXECUTION_ATTEMPTS_DESC =
order by execution attempts descending.
"-executionAttempts"