Class: Kaltura::Constants::BatchJob::Status
- Inherits:
-
Object
- Object
- Kaltura::Constants::BatchJob::Status
- Defined in:
- lib/kaltura/constants/batch_job.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- PENDING =
pending status
0- QUEUED =
queued status
1- PROCESSING =
processing status
2- PROCESSED =
processed status
3- MOVEFILE =
moving the file status
4- FINISHED =
finished status
5- FAILED =
failed state
6- ABORTED =
aborted state
7- ALMOST_DONE =
nearly completed status
8- RETRY =
retrying status
9- FATAL =
fatal error state
10- DONT_PROCESS =
unable to process state
11