Class: Kaltura::Constants::CategoryOrderBy
- Inherits:
-
Object
- Object
- Kaltura::Constants::CategoryOrderBy
- Defined in:
- lib/kaltura/constants/category_order_by.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- DEPTH_ASC =
order by depth ascending.
"+depth"- DEPTH_DESC =
order by depth descending.
"-depth"- FULL_NAME_ASC =
order by full name ascending.
"+fullName"- FULL_NAME_DESC =
order by full name descending.
"-fullName"- CREATED_AT_ASC =
order by created_at ascending.
"+createdAt"- CREATED_AT_DESC =
order by created_at descending.
"-createdAt"