Class: Kaltura::Constants::ContainerFormat
- Inherits:
-
Object
- Object
- Kaltura::Constants::ContainerFormat
- Defined in:
- lib/kaltura/constants/container_format.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- FLV =
flash video.
"flv"- MP4 =
MPEG-4 video
"mp4"- AVI =
audio video interleave file
"avi"- MOV =
Apple Quicktime Movie
"mov"- MP3 =
mp3 Audio
"mp3"- OGG =
ogg-vorbis video
"ogg"- WMV =
windows media video
"wmv"- ISMV =
iMovie file? Unsure of this one.
"ismv"