Class: Kaltura::Constants::DurationType
- Inherits:
-
Object
- Object
- Kaltura::Constants::DurationType
- Defined in:
- lib/kaltura/constants/duration_type.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- NOT_AVAILABLE =
unavailable duration.
"notavailable"- SHORT =
short duration.
"short"- MEDIUM =
medium duration.
"medium"- LONG =
long duration.
"long"