Class: Kaltura::Constants::Entry::ModerationStatus
- Inherits:
-
Object
- Object
- Kaltura::Constants::Entry::ModerationStatus
- Defined in:
- lib/kaltura/constants/entry.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- PENDING_MODERATION =
status prior after addition
1- APPROVED =
approved state
2- REJECTED =
rejected state
3- FLAGGED_FOR_REVIEW =
pending flags are present
5- AUTO_APPROVED =
approved without moderation
6