Class: Kaltura::Constants::ITunesSyndicationFeed::Categories
- Inherits:
-
Object
- Object
- Kaltura::Constants::ITunesSyndicationFeed::Categories
- Defined in:
- lib/kaltura/constants/i_tunes_syndication_feed/categories.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- ARTS =
The Arts
"Arts"- ARTS_DESIGN =
Arts and Design
"Arts/Design"- ARTS_FASHION_BEAUTY =
Arts, Fashion & Beauty
"Arts/Fashion & Beauty"- ARTS_FOOD =
Arts and Food
"Arts/Food"- ARTS_LITERATURE =
Arts and Literature
"Arts/Literature"- ARTS_PERFORMING_ARTS =
Performing Arts
"Arts/Performing Arts"- ARTS_VISUAL_ARTS =
The Visual Arts
"Arts/Visual Arts"- BUSINESS =
Business
"Business"- BUSINESS_BUSINESS_NEWS =
Business News
"Business/Business News"- BUSINESS_CAREERS =
Careers
"Business/Careers"- BUSINESS_INVESTING =
Investing
"Business/Investing"- BUSINESS_MANAGEMENT_MARKETING =
Management and Marketing
"Business/Management & Marketing"- BUSINESS_SHOPPING =
Business Shopping
"Business/Shopping"- COMEDY =
Comedy
"Comedy"- EDUCATION =
Education
"Education"- EDUCATION_TECHNOLOGY =
Educational Technology
"Education/Education Technology"- EDUCATION_HIGHER_EDUCATION =
Higher Ed
"Education/Higher Education"- EDUCATION_K_12 =
Primary education
"Education/K-12"- EDUCATION_LANGUAGE_COURSES =
Language courses.
"Education/Language Courses"- EDUCATION_TRAINING =
Educational training
"Education/Training"- GAMES_HOBBIES =
Games & Hobbies.
"Games & Hobbies"- GAMES_HOBBIES_AUTOMOTIVE =
Automotive Hobbies
"Games & Hobbies/Automotive"- GAMES_HOBBIES_AVIATION =
Aviation
"Games & Hobbies/Aviation"- GAMES_HOBBIES_HOBBIES =
Games & Hobbies
"Games & Hobbies/Hobbies"- GAMES_HOBBIES_OTHER_GAMES =
Other Games
"Games & Hobbies/Other Games"- GAMES_HOBBIES_VIDEO_GAMES =
Video Games
"Games & Hobbies/Video Games"- GOVERNMENT_ORGANIZATIONS =
Governmental Organizations
"Government & Organizations"- GOVERNMENT_ORGANIZATIONS_LOCAL =
Local Government Organizations
"Government & Organizations/Local"- GOVERNMENT_ORGANIZATIONS_NATIONAL =
National Government Organizations
"Government & Organizations/National"- GOVERNMENT_ORGANIZATIONS_NON_PROFIT =
Non-profits
"Government & Organizations/Non-Profit"- GOVERNMENT_ORGANIZATIONS_REGIONAL =
Regional Governmental Organizations
"Government & Organizations/Regional"- HEALTH =
Health
"Health"- HEALTH_ALTERNATIVE_HEALTH =
Alternative Health
"Health/Alternative Health"- HEALTH_FITNESS_NUTRITION =
Fitness and Nutrition
"Health/Fitness & Nutrition"- HEALTH_SELF_HELP =
Self-Help
"Health/Self-Help"- HEALTH_SEXUALITY =
Health & Sexuality
"Health/Sexuality"- KIDS_FAMILY =
Kids & Family
"Kids & Family"- MUSIC =
Music
"Music"- NEWS_POLITICS =
News and Policitcs
"News & Politics"- RELIGION_SPIRITUALITY =
Religion and Spirituality
"Religion & Spirituality"- RELIGION_SPIRITUALITY_BUDDHISM =
Buddhism
"Religion & Spirituality/Buddhism"- RELIGION_SPIRITUALITY_CHRISTIANITY =
Christianity
"Religion & Spirituality/Christianity"- RELIGION_SPIRITUALITY_HINDUISM =
Hinduism
"Religion & Spirituality/Hinduism"- RELIGION_SPIRITUALITY_ISLAM =
Islam
"Religion & Spirituality/Islam"- RELIGION_SPIRITUALITY_JUDAISM =
Judaism
"Religion & Spirituality/Judaism"- RELIGION_SPIRITUALITY_OTHER =
Other Religions
"Religion & Spirituality/Other"- RELIGION_SPIRITUALITY_SPIRITUALITY =
Spirituality
"Religion & Spirituality/Spirituality"- SCIENCE_MEDICINE =
Science & Medicine
"Science & Medicine"- SCIENCE_MEDICINE_MEDICINE =
Medicine
"Science & Medicine/Medicine"- SCIENCE_MEDICINE_NATURAL_SCIENCES =
Natural Sciences
"Science & Medicine/Natural Sciences"- SCIENCE_MEDICINE_SOCIAL_SCIENCES =
Social Sciences
"Science & Medicine/Social Sciences"- SOCIETY_CULTURE =
Society and Culture
"Society & Culture"- SOCIETY_CULTURE_HISTORY =
History
"Society & Culture/History"- SOCIETY_CULTURE_PERSONAL_JOURNALS =
Personal Journals
"Society & Culture/Personal Journals"- SOCIETY_CULTURE_PHILOSOPHY =
Philsophy
"Society & Culture/Philosophy"- SOCIETY_CULTURE_PLACES_TRAVEL =
Places & Travel
"Society & Culture/Places & Travel"- SPORTS_RECREATION =
Sports and Recreation
"Sports & Recreation"- SPORTS_RECREATION_AMATEUR =
Amateur Sports & Recreation
"Sports & Recreation/Amateur"- SPORTS_RECREATION_COLLEGE_HIGH_SCHOOL =
High School & College Sports
"Sports & Recreation/College & High School"- SPORTS_RECREATION_OUTDOOR =
Outdoor Recreation
"Sports & Recreation/Outdoor"- SPORTS_RECREATION_PROFESSIONAL =
Professional Sports
"Sports & Recreation/Professional"- TECHNOLOGY =
Technology
"Technology"- TECHNOLOGY_GADGETS =
Gadgets
"Technology/Gadgets"- TECHNOLOGY_TECH_NEWS =
Tech news
"Technology/Tech News"- TECHNOLOGY_PODCASTING =
Podcasting
"Technology/Podcasting"- TECHNOLOGY_SOFTWARE_HOW_TO =
Software how-to's
"Technology/Software How-To"- TV_FILM =
TV & Film
"TV & Film"