Class: Kaltura::Constants::ITunesSyndicationFeed::OrderBy
- Inherits:
-
Object
- Object
- Kaltura::Constants::ITunesSyndicationFeed::OrderBy
- Defined in:
- lib/kaltura/constants/i_tunes_syndication_feed.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- PLAYLIST_ID_ASC =
order by playlist_id ascending.
"+playlistId"- PLAYLIST_ID_DESC =
order by playlist_id descending.
"-playlistId"- NAME_ASC =
order by name ascending.
"+name"- NAME_DESC =
order by name descending.
"-name"- TYPE_ASC =
order by type ascending.
"+type"- TYPE_DESC =
order by type descending.
"-type"- CREATED_AT_ASC =
order by created_at ascending.
"+createdAt"- CREATED_AT_DESC =
order by created_at descending.
"-createdAt"