Class: Kaltura::Constants::LiveStreamEntryOrderBy
- Inherits:
-
Object
- Object
- Kaltura::Constants::LiveStreamEntryOrderBy
- Defined in:
- lib/kaltura/constants/live_stream_admin_entry_order_by.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- MEDIA_TYPE_ASC =
order by media type ascending
"+mediaType"- MEDIA_TYPE_DESC =
order by media type descending
"-mediaType"- PLAYS_ASC =
order by plays ascending
"+plays"- PLAYS_DESC =
order by plays descending
"-plays"- VIEWS_ASC =
order by views ascending
"+views"- VIEWS_DESC =
order by views descending
"-views"- DURATION_ASC =
order by duration ascending
"+duration"- DURATION_DESC =
order by duration descending
"-duration"- MS_DURATION_ASC =
order by millisecond duration ascending
"+msDuration"- MS_DURATION_DESC =
order by millisecond duration descending
"-msDuration"- NAME_ASC =
order by name ascending
"+name"- NAME_DESC =
order by name descending
"-name"- MODERATION_COUNT_ASC =
order by moderation count ascending
"+moderationCount"- MODERATION_COUNT_DESC =
order by moderation count descending
"-moderationCount"- CREATED_AT_ASC =
order by created at ascending
"+createdAt"- CREATED_AT_DESC =
order by created at descending
"-createdAt"- RANK_ASC =
order by rank ascending
"+rank"- RANK_DESC =
order by rank descending
"-rank"