Class: Kaltura::Constants::Partner::OrderBy
- Inherits:
-
Object
- Object
- Kaltura::Constants::Partner::OrderBy
- Defined in:
- lib/kaltura/constants/partner.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- ID_ASC =
order by ID ascending
"+id"- ID_DESC =
order by ID descending
"-id"- NAME_ASC =
order by name ascending
"+name"- NAME_DESC =
order by name descending
"-name"- WEBSITE_ASC =
order by website ascending
"+website"- WEBSITE_DESC =
order by website descending
"-website"- CREATED_AT_ASC =
order by created_at ascending
"+createdAt"- CREATED_AT_DESC =
order by created_at descending
"-createdAt"- ADMIN_NAME_ASC =
order by admin name ascending
"+adminName"- ADMIN_NAME_DESC =
order by admin name descending
"-adminName"- ADMIN_EMAIL_ASC =
order by admin email ascending
"+adminEmail"- ADMIN_EMAIL_DESC =
order by admin email descending
"-adminEmail"- STATUS_ASC =
order by status ascending
"+status"- STATUS_DESC =
order by status descending
"-status"