Class: Kaltura::Constants::SourceType
- Inherits:
-
Object
- Object
- Kaltura::Constants::SourceType
- Defined in:
- lib/kaltura/constants/source_type.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- FILE =
Sourced by a file
1- WEBCAM =
Sourced from a webcam recording
2- URL =
Sourced by an external URL
5- SEARCH_PROVIDER =
Sourced by a website search.
6- AKAMAI_LIVE =
Sourced from Akamai.
29