Class: Kaltura::Constants::Stats::KmcEventType
- Inherits:
-
Object
- Object
- Kaltura::Constants::Stats::KmcEventType
- Defined in:
- lib/kaltura/constants/stats/kmc_event_type.rb
Overview
The constants module will soon be depreciated into an Enumeration module to be more in line with the C# API client's namespacing.
Constant Summary collapse
- CONTENT_PAGE_VIEW =
A page with a KDP widget is viewed.
1001- CONTENT_ADD_PLAYLIST =
A playable entry is added to a playlist.
1010- CONTENT_EDIT_PLAYLIST =
A playist is edited.
1011- CONTENT_DELETE_PLAYLIST =
Content is removed from a playlist.
1012- CONTENT_DELETE_ITEM =
A property is removed from an entry.
1058- CONTENT_EDIT_ENTRY =
An entry is edited.
1013- CONTENT_CHANGE_THUMBNAIL =
An entry's thumbnail is changed.
1014- CONTENT_ADD_TAGS =
Tags are added to an entry.
1015- CONTENT_REMOVE_TAGS =
Tags are removed from an entry.
1016- CONTENT_ADD_ADMIN_TAGS =
Administrative tags are added to an entry.
1017- CONTENT_REMOVE_ADMIN_TAGS =
Administrative tags are removed from an entry.
1018- CONTENT_DOWNLOAD =
An entry/flavor is downloaded.
1019- CONTENT_APPROVE_MODERATION =
An entry is appproved.
1020- CONTENT_REJECT_MODERATION =
An entry is rejected.
1021- CONTENT_BULK_UPLOAD =
The Batch uploaded use used.
1022- CONTENT_ADMIN_KCW_UPLOAD =
The KCW is used to upload content.
1023- CONTENT_CONTENT_GO_TO_PAGE =
An entry is clicked, bringing up a detailed menu.
1057- CONTENT_ENTRY_DRILLDOWN =
A dropdown is entered from the entry menu.
1088- CONTENT_OPEN_PREVIEW_AND_EMBED =
the preview and embed link is clicked.
1089- ACCOUNT_CHANGE_PARTNER_INFO =
The accounts API information is changed.
1030- ACCOUNT_CHANGE_LOGIN_INFO =
The accounts login information is changed.
1031- ACCOUNT_CONTACT_US_USAGE =
The accounts contact information is changed.
1032- ACCOUNT_UPDATE_SERVER_SETTINGS =
The accounts server settings are changed.
1033- ACCOUNT_ACCOUNT_OVERVIEW =
The account overview settings are changed.
1034- ACCOUNT_ACCESS_CONTROL =
The access control for an account is modified.
1035- ACCOUNT_TRANSCODING_SETTINGS =
The default transcoding settings are modified.
1036- ACCOUNT_ACCOUNT_UPGRADE =
The Account is upgraded/downgraded.
1037- ACCOUNT_SAVE_SERVER_SETTINGS =
The Account udpates are saved to the database.
1038- ACCOUNT_ACCESS_CONTROL_DELETE =
The account's access has been revoked.
1039- ACCOUNT_SAVE_TRANSCODING_SETTINGS =
The accounts encoding settings have been saved to the database.
1040- LOGIN =
A KMC login event fires.
1041- DASHBOARD_IMPORT_CONTENT =
The content report is brought in on the dashboard.
1042- DASHBOARD_UPDATE_CONTENT =
The content report is updated on the dashbaord.
1043- DASHBOARD_ACCOUNT_CONTACT_US =
The Dashboard contact settings have changed.
1044- DASHBOARD_VIEW_REPORTS =
The view report for the Dashboard is updated.
1045- DASHBOARD_EMBED_PLAYER =
The player is embedded on the Dashboard report is updated.
1046- DASHBOARD_EMBED_PLAYLIST =
The dashboard playlist is updated.
1047- DASHBOARD_CUSTOMIZE_PLAYERS =
The dashboard player is customized.
1048- APP_STUDIO_NEW_PLAYER_SINGLE_VIDEO =
A new single video player is created.
1050- APP_STUDIO_NEW_PLAYER_PLAYLIST =
A new playlist player is created.
1051- APP_STUDIO_NEW_PLAYER_MULTI_TAB_PLAYLIST =
A new multi-tab playlist player is created.
1052- APP_STUDIO_EDIT_PLAYER_SINGLE_VIDEO =
A single video player is updated.
1053- APP_STUDIO_EDIT_PLAYER_PLAYLIST =
A playlist player is updated.
1054- APP_STUDIO_EDIT_PLAYER_MULTI_TAB_PLAYLIST =
A multitab playlist player is updated.
1055- APP_STUDIO_DUPLICATE_PLAYER =
A player is duplicated.
1056- REPORTS_AND_ANALYTICS_BANDWIDTH_USAGE_TAB =
The bandwidth usage report is updated.
1070- REPORTS_AND_ANALYTICS_CONTENT_REPORTS_TAB =
The content reports tab is updated.
1071- REPORTS_AND_ANALYTICS_USERS_AND_COMMUNITY_REPORTS_TAB =
The user community report is updated.
1072- REPORTS_AND_ANALYTICS_TOP_CONTRIBUTORS =
The top contributors report is updated.
1073- REPORTS_AND_ANALYTICS_MAP_OVERLAYS =
The map overlays report is updated.
1074- REPORTS_AND_ANALYTICS_TOP_SYNDICATIONS =
The top syndications report is updated.
1075- REPORTS_AND_ANALYTICS_TOP_CONTENT =
The top content report is updated.
1076- REPORTS_AND_ANALYTICS_CONTENT_DROPOFF =
The content dropoff report is updated.
1077- REPORTS_AND_ANALYTICS_CONTENT_INTERACTIONS =
The content intearaction report is updated.
1078- REPORTS_AND_ANALYTICS_CONTENT_CONTRIBUTIONS =
The content contributions report is updated.
1079- REPORTS_AND_ANALYTICS_VIDEO_DRILL_DOWN =
The dropdowns on the reports section is clicked.
1080- REPORTS_AND_ANALYTICS_CONTENT_DRILL_DOWN_INTERACTION =
The dropdown on the report section is used.
1081- REPORTS_AND_ANALYTICS_CONTENT_CONTRIBUTIONS_DRILLDOWN =
The content contributions dropdown is selected.
1082- REPORTS_AND_ANALYTICS_VIDEO_DRILL_DOWN_DROPOFF =
The content dropoff dropdown is selected.
1083- REPORTS_AND_ANALYTICS_MAP_OVERLAYS_DRILLDOWN =
The map overlays dropdown is selected.
1084- REPORTS_AND_ANALYTICS_TOP_SYNDICATIONS_DRILL_DOWN =
The top syndications dropdown is selected.
1085- REPORTS_AND_ANALYTICS_BANDWIDTH_USAGE_VIEW_MONTHLY =
The monthly bandwith report.
1086- REPORTS_AND_ANALYTICS_BANDWIDTH_USAGE_VIEW_YEARLY =
The yearly bandwith report.
1087